==> aws-cdk-scala-opsworks_2.12-0.3.0-sources.jar: io/burkard/cdk/services/opsworks/CfnApp.scala <==
package io.burkard.cdk.services.opsworks

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnApp {

  def apply(
    internalResourceId: String,
    name: String,
    stackId: String,
    `type`: String,
    sslConfiguration: Option[software.amazon.awscdk.services.opsworks.CfnApp.SslConfigurationProperty] = None,
    shortname: Option[String] = None,
    description: Option[String] = None,
    domains: Option[List[String]] = None,
    attributes: Option[Map[String, String]] = None,
    appSource: Option[software.amazon.awscdk.services.opsworks.CfnApp.SourceProperty] = None,
    environment: Option[List[_]] = None,
    enableSsl: Option[Boolean] = None,
    dataSources: Option[List[_]] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.opsworks.CfnApp =
    software.amazon.awscdk.services.opsworks.CfnApp.Builder
      .create(stackCtx, internalResourceId)
      .name(name)
      .stackId(stackId)
      .`type`(`type`)
      .sslConfiguration(sslConfiguration.orNull)
      .shortname(shortname.orNull)
      .description(description.orNull)
      .domains(domains.map(_.asJava).orNull)
      .attributes(attributes.map(_.asJava).orNull)
      .appSource(appSource.orNull)
      .environment(environment.map(_.asJava).orNull)
      .enableSsl(enableSsl.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .dataSources(dataSources.map(_.asJava).orNull)
      .build()
}

==> aws-cdk-scala-opsworks_2.13-0.1.3-sources.jar: io/burkard/cdk/services/opsworks/CfnApp.scala <==
package io.burkard.cdk.services.opsworks

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnApp {

  def apply(
    internalResourceId: String,
    name: Option[String] = None,
    sslConfiguration: Option[software.amazon.awscdk.services.opsworks.CfnApp.SslConfigurationProperty] = None,
    shortname: Option[String] = None,
    description: Option[String] = None,
    domains: Option[List[String]] = None,
    attributes: Option[Map[String, String]] = None,
    stackId: Option[String] = None,
    appSource: Option[software.amazon.awscdk.services.opsworks.CfnApp.SourceProperty] = None,
    environment: Option[List[_]] = None,
    enableSsl: Option[Boolean] = None,
    dataSources: Option[List[_]] = None,
    `type`: Option[String] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.opsworks.CfnApp =
    software.amazon.awscdk.services.opsworks.CfnApp.Builder
      .create(stackCtx, internalResourceId)
      .name(name.orNull)
      .sslConfiguration(sslConfiguration.orNull)
      .shortname(shortname.orNull)
      .description(description.orNull)
      .domains(domains.map(_.asJava).orNull)
      .attributes(attributes.map(_.asJava).orNull)
      .stackId(stackId.orNull)
      .appSource(appSource.orNull)
      .environment(environment.map(_.asJava).orNull)
      .enableSsl(enableSsl.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .dataSources(dataSources.map(_.asJava).orNull)
      .`type`(`type`.orNull)
      .build()
}
